GeminiContentConverter class
A class to convert between the generic ChatMessage and the firebase_ai
specific Content classes.
This class is responsible for translating the abstract ChatMessage
representation into the concrete firebase_ai.Content representation
required by the firebase_ai package.
Note on Image Handling: ImagePart instances that are provided with
only a url (and no bytes or base64 data) will be converted to a
simple text representation of the URL (e.g., "Image at {url}"). The image
data is not automatically fetched from the URL by this converter.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFirebaseAiContent(
Iterable< ChatMessage> messages) → List<Content> -
Converts a list of
ChatMessageobjects to a list offirebase_ai.Contentobjects. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited